@@ -34,7 +34,7 @@ function(X, center=TRUE, shape=TRUE, eps.S=1e-5, na.action=na.fail,...)
 
      else if(is.numeric(shape))
      # center needs to be set:
-      if (center) center<-ICSNP:::mat.sqrt(shape)%*%spatial.median(X%*% syminv(ICSNP:::mat.sqrt(shape)),...)
+      if (center) center<-mat.sqrt(shape)%*%spatial.median(X%*% syminv(mat.sqrt(shape)),...)
       else center<-rep(0,p)
  
      else 
@@ -63,8 +63,8 @@ function(X, center=TRUE, shape=TRUE, eps.S=1e-5, na.action=na.fail,...)
       }
     }
 
-    y<-sweep(X,2,center)%*%syminv(ICSNP:::mat.sqrt(shape))
-    y.norm <- ICSNP:::norm(y) 
+    y<-sweep(X,2,center)%*%syminv(mat.sqrt(shape))
+    y.norm <- SpatialNP:::norm(y) 
     spatial.signs<-sweep(y,1,y.norm,"/")
     ind.eps.S <- which(y.norm <= eps.S)
     if (length(ind.eps.S != 0)){
